/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.jaccal.command.gsm;

import com.jaccal.CardException;
import com.jaccal.command.gsm.GSM11_11;
import com.jaccal.command.iso.ISOUpdateRecord;


/**
 * 
 * @author Aurelien Delaitre
 *
 */
public class GSMUpdateRecord extends ISOUpdateRecord{
    public final static byte NEXT_REC = (byte)2;
    public final static byte PREV_REC = (byte)3;
    public final static byte CURRENT_REC = (byte)4;

    /**
     * Construct a GSM command that updates a record file.
     * <ul>
     * <li>NEXT_REC: reads the next record (recordNumber is not significant)</li>
     * <li>PREV_REC: reads the previous record (recordNumber is not significant)</li>
     * <li>CURRENR_REC: reads the current record or the one specified by recordNumber</li>
     * </ul>
     * @param recordNumber
     * @param dataToUpdate
     * @param mode
     * @throws CardException
     */
    public GSMUpdateRecord(String recordNumber, String dataToUpdate, byte mode) throws CardException {
        super(recordNumber, dataToUpdate);
        if((mode != NEXT_REC) && (mode != PREV_REC) && (mode != CURRENT_REC))
            throw new CardException("(UpdateRecord) mode is invalid. Authorised values are: NEXT_REC, PREV_REC or CURRENT_REC");
        
        super.setCla(GSM11_11.CLA_GSM11_11);
      	
        setP2(mode);     
    }
  
    /* (non-Javadoc)
     * @see com.jaccal.command.Command#setCla(byte)
     */
    public void setCla(byte cla){
    }
 }
