/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.jaccal.command.gsm;

import com.jaccal.CardException;
import com.jaccal.command.iso.ISOVerifyChv;
import com.jaccal.util.NumUtil;
 
/**
 * 
 * @author Aurelien Delaitre
 *
 */
public class GSMVerifyChvEx extends ISOVerifyChv{
    public final static String CHV1 = "01";
    public final static String CHV2 = "02";
    public final static String ADM1 = "0A";
    public final static String ADM2 = "0B";
    public final static String ADM3 = "0C";
    public final static String ADM4 = "0D";
    
   
    public GSMVerifyChvEx(String chvRefId, String chv) throws CardException{
        super(chvRefId,chv);
        super.setCla(GSM11_11.CLA_GSM11_11);
        
        // Check chv length. must be >= 4
        if((chv.length() < 4) || (chv.length() > 8))
        	throw new CardException("CHV value should be at least 4 byte long and less than 8 byte long");
         
        // Check the CHV reference ID value
        if(		(chvRefId.compareTo(CHV1) != 0) && (chvRefId.compareTo(CHV2) != 0) &&
        		(chvRefId.compareTo(ADM1) != 0) && (chvRefId.compareTo(ADM2) != 0) &&
        		(chvRefId.compareTo(ADM3) != 0) && (chvRefId.compareTo(ADM4) != 0) )
        	throw new CardException("Bad CHV reference ID");

        // Convert the chv in string
		StringBuilder paddedChv = new StringBuilder();
		for(char c: chv.toCharArray()){
			paddedChv.append(NumUtil.hex2String((byte)c));
		}
		
		// Add the padding to FF until 16 digits
		paddedChv.append( "FFFFFFFFFFFFFFFF" );
		
		byte[] b = NumUtil.toStringHex(paddedChv.substring( 0, 16 ).toString());
		setData(b);
		setLc((byte)b.length);		
    }

    /* (non-Javadoc)
     * @see com.jaccal.command.Command#setCla(byte)
     */
    public void setCla(byte cla){
    }      
}
