/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.jaccal.command.gsm.axalto;

import com.jaccal.command.Command;
import com.jaccal.CardException;
import com.jaccal.util.NumUtil;

/**
 * 
 * @author Aurelien Delaitre
 *
 */

// Based on Axalto USIMera 3 128K smartcards
public class AxaltoVerifyKey extends Command {
    public AxaltoVerifyKey(byte channel, byte keyRefId, String key) throws CardException{
    	// Check the channel
    	if(0 > channel || channel > 3)
    		throw new CardException("Channel should be 0 to 3");
    	
    	setCla((byte)(0xf0 | channel));
    	setIns((byte)0x2a);
    	
    	// Check the key index
    	if(0 > keyRefId || keyRefId > 15)
    		throw new CardException("Key index should be 1 to 15");

    	setP1((byte)0);
    	setP2(keyRefId);
    	
        // Check key length
        if(key.length() / 2 > 255)
        	throw new CardException("ADM key should be less than 255 bytes long");
        
        byte [] bkey = NumUtil.toStringHex(key);
        setLc((byte)bkey.length);
        setData(bkey);		
    }
    
    public void setIns(byte ins){
    	this.ins = ins;
    }
}
