/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.jaccal.util.NumUtil;
import com.simfill.LogManager;
import com.simfill.Registry;

import java.util.Arrays;
import java.lang.StringBuffer;

// Stores the data to be stored in EF_ELP
public class ELP extends TransparentFile
{
	// Langages are specified in ISO 639-1
	public static final String [] LANGUAGES =
	{
		"aa", "ab", "ae", "af", "ak", "am", "an", "ar", "as", "av", "ay", "az",
		"ba", "be", "bg", "bh", "bi", "bm", "bn", "bo", "br", "bs", 
		"ca", "ce", "ch", "co", "cr", "cs", "cu", "cv", "cy",
		"da", "de", "dv", "dz",
		"ee", "el", "en", "eo", "es", "et", "eu",
		"fa", "ff", "fi", "fj", "fo", "fr", "fy",
		"ga", "gd", "gl", "gn", "gu", "gv",
		"ha", "he", "hi", "ho", "hr", "ht", "hu", "hy", "hz",
		"ia", "id", "ie", "ig", "ii", "ik", "io", "is", "it", "iu",
		"ja", "jv",
		"ka", "kg", "ki", "kj", "kk", "kl", "km", "kn", "ko", "kr", "ks", "ku", "kv", "kw", "ky",
		"la", "lb", "lg", "li", "ln", "lo", "lt", "lu", "lv",
		"mg", "mh", "mi", "mk", "ml", "mn", "mr", "ms", "mt", "my",
		"na", "nb", "nd", "ne", "ng", "nl", "nn", "no", "nr", "nv", "ny",
		"oc", "oj", "om", "or", "os",
		"pa", "pi", "pl", "ps", "pt", 
		"qu",
		"rm", "rn", "ro", "ru", "rw",
		"sa", "sc", "sd", "se", "sg", "si", "sk", "sl", "sm", "sn", "so", "sq", "sr", "ss", "st", "su", "sv", "sw",
		"ta", "te", "tg", "th", "ti", "tk", "tl", "tn", "to", "tr", "ts", "tt", "tw", "ty",
		"ug", "uk", "ur", "uz",
		"ve", "vi", "vo",
		"wa", "wo",
		"xh",
		"yi", "yo",
		"za", "zh", "zu"
	};
	
	public ELP( int size )
	{
		super( size );
		
		m_lang = new byte[ getSize() ];
		
		for( int index = 0; index < size; ++index )
		{
			m_lang[ index ] = ( byte )0xff;
		}
	}
	
	public void setLang( int index, String lang )
	{
		if( 0 <= index && index < getSize() / 2 )
		{
			if( 0 <= Arrays.binarySearch( LANGUAGES, lang ) )
			{
				System.arraycopy( Charset.translate( lang ), 0, m_lang, 2 * index, 2 );
			}
			else
			{
				LogManager.getInstance().log( "warn", "The language \"" + lang + "\" is not defined in ISO 639-1.", true );
			}
		}
		else
		{
			LogManager.getInstance().log( "warn", "The storage index for the language preference is out of range.", true );
		}
	}

	public String toHex()
	{
		return NumUtil.hex2String( m_lang );
	}
	
	public String toString()
	{
		StringBuffer report = new StringBuffer();
		String newline = Registry.getInstance().get( "report.newline" );

		for( int it = 0; it < m_lang.length / 2; ++it )
		{
			report.append( it + 1 );
			report.append( ": " );
			report.append( m_lang[ 2 * it ] == -1 ? "empty" : Charset.untranslate( m_lang, 2 * it, 2 ) );
			report.append( newline );
		}

		return report.toString();
	}

	// Languages
	private byte [] m_lang;
}
