/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

public abstract class SMSUserData extends SMS
{
	// TP-Data-Coding-Scheme (TP-DCS), according to 3GPP TS 23.038
	public static final byte DCS_7BITS_DEFAULT    = 0x00;
	public static final byte DCS_8BITS            = 0x01;
	public static final byte DCS_16BITS_UCS2      = 0x08;
	public static final byte DCS_RESERVED         = 0x0f;

	protected byte m_dcs;
	
	// TP-User-Data-Length (TP-UDL), according to 3GPP TS 23.040
	protected int m_udl; 
	
	// TP-User-Data (TP-UD), according to 3GPP TS 23.040
	protected String m_ud;
	
	public SMSUserData( short size ) throws Exception
	{
		super( size );
		
		setDCS( DCS_7BITS_DEFAULT );
		setUD( "" );
	}
	
	public void setDCS( byte dcs )
	{
		m_dcs = dcs;
	}
	
	public void setUD( String ud )
	{
		m_ud  = ud;
		m_udl = ud.length();
	}
}