/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.FileWriter;
import java.io.IOException;

import javax.swing.JFileChooser;

public class LogController implements ActionListener
{
	public LogController( LogModel model, NewView view )
	{
		m_model = model;
		m_view  = view;
		
		m_view.addFilterListener( this );
		m_view.addClearListener( this );
		m_view.addSaveListener( this );
	}
	
	public void actionPerformed( ActionEvent event )
	{
		if( event.getActionCommand().equals( "filter" ) )
		{
			try
			{
				m_model.setFilter( m_view.getFilterLabel() );
			}
			catch( Exception e )
			{
				System.err.println( e );
				System.exit( -1 );
			}
		}
		else if( event.getActionCommand().equals( "clear" ) )
		{
			m_model.clear();
		}
		else if( event.getActionCommand().equals( "save" ) )
		{
			final JFileChooser fc = new JFileChooser( "./log" );
			
			if ( fc.showOpenDialog( m_view ) == JFileChooser.APPROVE_OPTION )
			{
				try
				{
					FileWriter fw = new FileWriter( fc.getSelectedFile() );
					fw.write( "<html><head><meta http-equiv='Content-Type' content='text/html; charset=UTF-8'></head><body>\n" + m_model.getLog() + "\n</body></html>" );
					fw.close();
				}
				catch( IOException e )
				{
					// FIXME
					System.err.println( e );
				}
			}
		}
	}
	
	private LogModel m_model;
	private NewView  m_view;
}
