/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.event.ActionListener;
import java.util.Observable;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JEditorPane;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

public class NewView extends JFrame implements java.util.Observer
{
	public NewView( MainModel mmodel, LogModel lmodel )
	{
		// Initiate the GUI frame
		super( "SIMfill" );
		setDefaultCloseOperation( EXIT_ON_CLOSE );
		setLayout( new BorderLayout() );
		setPreferredSize( new Dimension( 1024, 768 ) );

		JPanel pnl = new JPanel( new BorderLayout() );
		JPanel subpnl = new JPanel( new GridLayout( 1, 3 ) );
		pnl.add( subpnl, BorderLayout.NORTH );

		m_btnLoadData = createButton( "Load data", "loadData", "Load the XML file containing the data to be stored on the card" );
		m_btnLoadCard = createButton( "Load card info", "loadCard", "Load the XML file containing the configuration data of the card (type, PIN...)" );
		m_btnProceed  = createButton( "Proceed", "proceed", "Write data to the card" );
		m_btnProceed.setEnabled( false );
		subpnl.add( m_btnLoadData );
		subpnl.add( m_btnLoadCard );
		subpnl.add( m_btnProceed );
		
		pnl.add( new JLabel( "Filter: " ), BorderLayout.WEST );
		m_cbxFilter = new JComboBox( lmodel.getSeverity() );
		m_cbxFilter.setActionCommand( "filter" );
		m_cbxFilter.setEditable( false );
		pnl.add( m_cbxFilter, BorderLayout.CENTER );
		add( pnl, BorderLayout.NORTH );
		
		m_tpnLog = new JEditorPane();
		m_tpnLog.setAutoscrolls( true );
		m_tpnLog.setEditable( false );
		m_tpnLog.setContentType( "text/html" );
		
		JScrollPane sp = new JScrollPane( m_tpnLog );
		sp.setAutoscrolls( true );
		add( sp, BorderLayout.CENTER );

		subpnl = new JPanel( new GridLayout( 1, 2 ) );
		add( subpnl, BorderLayout.SOUTH );

		m_btnClear = createButton( "Clear", "clear", "Clear log" );
		subpnl.add( m_btnClear );

		m_btnSave = createButton( "Save", "save", "Save log to a file" );
		subpnl.add( m_btnSave );
		
		// Display the GUI
		pack();
		setVisible( true );
		
		// Connect the view to the model
		mmodel.addObserver( this );
		lmodel.addObserver( this );
		m_mmodel = mmodel;
		m_lmodel = lmodel;
		
		// Make sure the right filter is selected
		update( lmodel, null );
	}
	
	public void update( Observable model, Object o )
	{
		if( model == m_mmodel )
		{
			m_btnProceed.setEnabled( m_mmodel.isReady() );
		}
		else if( model == m_lmodel )
		{
			m_cbxFilter.setSelectedItem( m_lmodel.getFilter() );
			m_tpnLog.setText( m_lmodel.getLog() );
		}
	}

	public void addLoadDataListener( ActionListener al )
	{
		m_btnLoadData.addActionListener( al );
	}

	public void addLoadCardListener( ActionListener al )
	{
		m_btnLoadCard.addActionListener( al );
	}
	
	public void addProceedListener( ActionListener al )
	{
		m_btnProceed.addActionListener( al );
	}

	public void addFilterListener( ActionListener al )
	{
		m_cbxFilter.addActionListener( al );
	}
	
	public void addClearListener( ActionListener al )
	{
		m_btnClear.addActionListener( al );
	}
	
	public void addSaveListener( ActionListener al )
	{
		m_btnSave.addActionListener( al );
	}

	public String getFilterLabel()
	{
		return ( ( LogSeverity )m_cbxFilter.getSelectedItem() ).toString();
	}
	
	private JButton createButton( String text, String actionCommand, String toolTip )
	{
		JButton btn = new JButton( text );
		btn.setActionCommand( actionCommand );
		btn.setToolTipText( toolTip );
		
		return btn;
	}

	// Models of the view
	private MainModel m_mmodel;
	private LogModel  m_lmodel;

	// Buttons and stuff
	private JButton m_btnProceed, m_btnLoadData, m_btnLoadCard;
	private JComboBox m_cbxFilter;
	private JEditorPane m_tpnLog;
	private JButton m_btnClear, m_btnSave;

	// Specified to avoid a warning
	private static final long serialVersionUID = 1L;
}
