/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill;

import com.simfill.gui.LogController;
import com.simfill.gui.LogModel;
import com.simfill.gui.MainController;
import com.simfill.gui.MainModel;
import com.simfill.gui.NewView;

public class SimFill
{	
	public static void main( String [] args )
	{	
		// Set up some reporting parameters
		Registry.getInstance().put( "report.newline", "<br>" + System.getProperty( "line.separator" ) );
		
		// Set up the log subsystem
		LogModel logModel = new LogModel();
		LogManager.setInstance( logModel );
		try
		{
			logModel.registerSeverity( "Error"      , 1 );
			logModel.registerSeverity( "Warning"    , 2 );
			logModel.registerSeverity( "Information", 5 );
			logModel.registerSeverity( "Report"     , 6 );
			logModel.registerSeverity( "Debug"      , 8 );
			logModel.registerSeverity( "All"        , 9 );
			
			logModel.registerNamespace( "err" , "#FF0000", 1 );
			logModel.registerNamespace( "warn", "#FF9900", 2 );
			logModel.registerNamespace( "info", "#111111", 5 );
			logModel.registerNamespace( "rprt", "#555555", 6 );
			logModel.registerNamespace( "excp", "#0033CC", 8 );
			logModel.registerNamespace( "adpu", "#9999FF", 9 );
			
			logModel.setFilter( "Information" );
		}
		catch( Exception e )
		{
			System.err.println( e );
			System.exit( -1 );
		}
		
		// Set up the main subsystem
		MainModel mainModel = new MainModel();
		
		// Create the GUI
		NewView newView = new NewView( mainModel, logModel );

		// Create the controllers
		new MainController( mainModel, newView );
		new LogController ( logModel,  newView );
	}
}
