/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.simfill.Registry;

import java.lang.StringBuffer;
import java.lang.String;

// Type-of-Address utility class
public class Address
{
	// Type Of Number (TON), according to 3GPP TS 23.040
	public static final byte TON_UNKNOWN          = 0x00;
	public static final byte TON_INTERNATIONAL    = 0x10;
	public static final byte TON_NATIONAL         = 0x20;
	public static final byte TON_NETWORK_SPECIFIC = 0x30;
	public static final byte TON_SUBSCRIBER       = 0x40;
	public static final byte TON_ALPHANUMERIC     = 0x50;
	public static final byte TON_ABBREVIATED      = 0x60;
	public static final byte TON_RESERVED         = 0x70;
	
	
	// Numbering Plan Identification (NPI), according to 3GPP TS 23.040
	public static final byte NPI_UNKNOWN                   = 0x00;
	public static final byte NPI_TELEPHONE                 = 0x01;
	public static final byte NPI_DATA                      = 0x03;
	public static final byte NPI_TELEX                     = 0x04;
	public static final byte NPI_SERVICE_CENTER_SPECIFIC_1 = 0x05;
	public static final byte NPI_SERVICE_CENTER_SPECIFIC_2 = 0x06;
	public static final byte NPI_NATIONAL                  = 0x08;
	public static final byte NPI_PRIVATE                   = 0x09;
	public static final byte NPI_ERMES                     = 0x0a;
	public static final byte NPI_RESERVED                  = 0x0f;
	
	public Address()
	{
		m_ton = TON_UNKNOWN;
		m_npi = NPI_UNKNOWN;
		m_number = "";
	}
	
	// Return a properly encoded 'type of address' byte, which is made of the TON and the NPI
	public byte getTypeOfAddress()
	{
		return ( byte )( 0x80 | m_ton | m_npi );
	}
	
	// Return the TON
	public byte getTON()
	{
		return m_ton;
	}
	
	// Return the NPI
	public byte getNPI()
	{
		return m_npi;
	}
	
	// Return the address
	public String getNumber()
	{
		return m_number;
	}
	
	// Set the TON
	public void setTON( byte ton )
	{
		m_ton = ton;
	}
	
	// Set the address
	public void setNumber( String number )
	{
		m_number = number;
	}
	
	// Set the NPI
	public void setNPI( byte npi )
	{
		m_npi = npi;
	}
	
	// Return a human-readable description of the content
	public String toString()
	{
		StringBuffer report = new StringBuffer();
		
		final String newline = Registry.getInstance().get( "report.newline" );
		
		report.append( " - TON: " );
		switch( m_ton )
		{
			case TON_UNKNOWN:          report.append( "Unknown"          ); break;
			case TON_INTERNATIONAL:    report.append( "International"    ); break;
			case TON_NATIONAL:         report.append( "National"         ); break;
			case TON_NETWORK_SPECIFIC: report.append( "Network specific" ); break;
			case TON_SUBSCRIBER:       report.append( "Subscriber"       ); break;
			case TON_ALPHANUMERIC:     report.append( "Alphanumeric"     ); break;
			case TON_ABBREVIATED:      report.append( "Abbreviated"      ); break;
			case TON_RESERVED:         report.append( "Reserved"         ); break;
			default:                   report.append( "INVALID"          );
		}
		report.append( newline );

		report.append( " - NPI: " );
		switch( m_npi )
		{
			case NPI_UNKNOWN:                   report.append( "Unknown"                     ); break;
			case NPI_TELEPHONE:                 report.append( "Telephone"                   ); break;
			case NPI_DATA:                      report.append( "Data"                        ); break;
			case NPI_TELEX:                     report.append( "Telex"                       ); break;
			case NPI_SERVICE_CENTER_SPECIFIC_1: report.append( "Service center specific (1)" ); break;
			case NPI_SERVICE_CENTER_SPECIFIC_2: report.append( "Service center specific (2)" ); break;
			case NPI_NATIONAL:                  report.append( "National"                    ); break;
			case NPI_PRIVATE:                   report.append( "Private"                     ); break;
			case NPI_ERMES:                     report.append( "Ermes"                       ); break;
			case NPI_RESERVED:                  report.append( "Reserved"                    ); break;
			default:                            report.append( "INVALID"                     );
		}
		report.append( newline );

		report.append( " - Number: " );
		report.append( m_number.length() == 0 ? "none" : m_number );
		report.append( newline );

		return report.toString();
	}
	
	// TON
	private byte m_ton;
	
	// NPI
	private byte m_npi;
	
	// Number
	private String m_number;
}
