/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.simfill.Registry;
import com.simfill.LogManager;

// Stores the ICCID data to be stored in EF_ICCID
public class ICCID extends TransparentFile
{
	public ICCID( int size ) throws Exception
	{
		super( size );
		
		if( getSize() != 10 )
		{
			throw new Exception( "ICCID: the size of the file EF_ICCID is not standard." );
		}
	}

	public void setICCID( String iccid )
	{
		m_iccid = iccid;
	}

	public String toHex()
	{
		StringBuilder storage = new StringBuilder();
		
		String iccid;

		if( m_iccid.length() > 20 )
		{
			iccid = m_iccid.substring( 0, 20 );
			LogManager.getInstance().log( "warn", "ICCID: the ICCID can't be longer than 20 digits. ICCID '" + m_iccid + "' will be toncated.", true );
		}
		else
		{
			iccid = m_iccid;
		}
		
		String padded = ( iccid + "ffffffffffffffffffffffffffff" ).substring( 0, 20 );
		
		for( int it = 0; it < 20; it += 2 )
		{
			storage.append( padded.charAt( it + 1 ) );
			storage.append( padded.charAt( it + 0 ) );
		}
		
		return storage.toString();
	}
	
	public String toString()
	{
		return "ICCID: " + ( m_iccid.length() > 20 ? m_iccid.substring( 0, 20 ) : m_iccid ) + Registry.getInstance().get( "report.newline" );
	}

	// ICCID
	private String m_iccid;
}
