/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.jaccal.util.NumUtil;

import com.simfill.Registry;

// Stores the PLMN data to be stored in EF_PLMNsel and EF_FPLMN
public class PLMN extends TransparentFile
{
	public PLMN( int size )
	{
		super( size );
		
		m_plmn = new byte[ getSize() ];
		
		for( int index = 0; index < size; ++index )
		{
			m_plmn[ index ] = ( byte )0xff;
		}
	}
	
	public void setMCC( int index, String mcc ) throws Exception
	{
		if( mcc.length() != 3 )
		{
			throw new Exception( "PLMN: the length of MCC should be 3 characters." );
		}
		if( index + 2 < getSize() )
		{
			m_plmn[ index + 0 ] = ( byte )( ( ( mcc.charAt( 1 ) - '0' ) << 4 ) + ( mcc.charAt( 0 ) - '0' ) );
			m_plmn[ index + 1 ] = ( byte )( (     m_plmn[ index + 1 ] & 0xf0 ) + ( mcc.charAt( 2 ) - '0' ) );
		}
		else
		{
			throw new Exception( "PLMN: the storage index for the MCC in PLMN is out of range." );
		}
	}

	public void setMNC( int index, String mnc ) throws Exception
	{
		switch( mnc.length() )
		{
			case 2:
			
				mnc += ( char )( 0xf + '0' );
				break;
				
			case 3:
				
				break;
				
			default:
				
				throw new Exception( "PLMN: the length of MNC should be 2 or 3 characters." );
		}

		if( index + 2 < getSize() )
		{
			m_plmn[ index + 1 ] = ( byte )( (    m_plmn[ index + 1 ] & 0xf ) + ( ( mnc.charAt( 2 ) - '0' ) << 4 ) );
			m_plmn[ index + 2 ] = ( byte )( ( ( mnc.charAt( 1 ) - '0' ) << 4 ) + ( mnc.charAt( 0 ) - '0' ) );
		}
		else
		{
			throw new Exception( "PLMN: the storage index for the MNC in PLMN is out of range." );
		}
	}	

	public String toHex()
	{
		return NumUtil.hex2String( m_plmn );
	}
	
	public String toString()
	{
		StringBuffer report = new StringBuffer();
		
		String newline = Registry.getInstance().get( "report.newline" );

		for( int it = 0; it < m_plmn.length; it += 3 )
		{
			byte b0, b1, b2;
			int mcc0, mcc1, mcc2;
			int mnc0, mnc1, mnc2;

			b0 = m_plmn[ it + 0 ];
			b1 = m_plmn[ it + 1 ];
			b2 = m_plmn[ it + 2 ];
			
			report.append( ( it / 3 ) + 1 );
			report.append( ":" );

			mcc0 = ( b0 & 0x0f ) >> 0;
			mcc1 = ( b0 & 0xf0 ) >> 4;
			mcc2 = ( b1 & 0x0f ) >> 0;

			mnc0 = ( b2 & 0x0f ) >> 0;
			mnc1 = ( b2 & 0xf0 ) >> 4;
			mnc2 = ( b1 & 0xf0 ) >> 4;
			
			if( ( mcc0 & mcc1 & mcc2 & mnc0 & mnc1 & mnc2 ) != 0xf )
			{
				report.append( " MCC=" );
				report.append( ( char )( mcc0 == 0xf ? ' ' : '0' + mcc0 ) );
				report.append( ( char )( mcc1 == 0xf ? ' ' : '0' + mcc1 ) );
				report.append( ( char )( mcc2 == 0xf ? ' ' : '0' + mcc2 ) );
				
				report.append( " MNC=" );
				report.append( ( char )( mnc0 == 0xf ? ' ' : '0' + mnc0 ) );
				report.append( ( char )( mnc1 == 0xf ? ' ' : '0' + mnc1 ) );
				report.append( ( char )( mnc2 == 0xf ? ' ' : '0' + mnc2 ) );
			}
			else
			{
				report.append( " (empty)" );
			}
			
			report.append( newline );
		}
		
		return report.toString();
	}

	// PLMNs
	private byte [] m_plmn;
}
