/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.simfill.LogManager;

import java.io.File;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;

public class SMSUserDataHeaderImage extends SMSUserDataHeaderElement
{
	protected SMSUserDataHeaderImage( int iei, int position, File source, int width, int height ) throws Exception
	{
		super( iei );
		
		// Load the image from the file
		BufferedImage i = ImageIO.read( source );
		
		// Check its size
		if( i.getWidth() != width || i.getHeight() != height )
		{
			LogManager.getInstance().log( "warn", "The size of the image '" + source.getPath() + "' is not " + width + "x" + height + ".", true );
			
			throw new Exception( "SMSUserDataHeaderImage: the file '" + source.getPath() + "' is not a " + width + "x" + height + " image." );
		}

		// Create the data buffer and store the position
		byte [] data = new byte[ ( ( width * height ) >> 3 ) + 1 ];
		data[ 0 ] = ( byte )position;
		
		// Convert the image to black and white and store it to the buffer
		for( int y = 0; y < height; ++y )
		{
			for( int x = 0; x < width; ++x )
			{
				int rgb = i.getRGB( x, y );
				int r = ( rgb & 0x00ff0000 ) >> 0x10;
				int g = ( rgb & 0x0000ff00 ) >> 0x08;
				int b = ( rgb & 0x000000ff ) >> 0x00;
				int m = ( r + g + g + b ) >> 2; // Use 25% red, 50% green, 25% blue

				// Threshold
				if( m < 0x8f )
				{
//					i.setRGB( x, y, 0xff000000 );
					data[ ( ( x + y * width ) >> 3 ) + 1 ] |= 1 << ( 7 - ( x & 0x7 ) );
				}
				else
				{
//					i.setRGB( x, y, 0xffffffff );
				}
			}
		}

		// TODO: Write a copy in the log directory for the report
		// ImageIO.write( i, "png", new File( "./log/img.png" ) );
		
		setData( data );
	}
	
	public String toString()
	{
		StringBuilder storage = new StringBuilder();
		
		// FIXME: check the size of the array
		byte [] data = getData();
		
		storage.append( " - type: image, position: " );
		storage.append( data[ 0 ] );

		return storage.toString();
	}
}
