/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gui;

import java.io.File;
import java.io.IOException;

import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.SchemaFactory;

import org.xml.sax.SAXException;

import com.simfill.FillingThread;
import com.simfill.LogManager;

public class MainModel extends java.util.Observable
{	
	public MainModel()
	{
		// Create the XML schema parser
		m_schemaFactory = SchemaFactory.newInstance( "http://www.w3.org/2001/XMLSchema" );
	}
	
	public void loadDataFile( File selectedDataFile )
	{
		try
		{
			m_dataFile = null;
			m_schemaFactory.newSchema( new File( "data/data.xsd" ) ).newValidator().validate( new StreamSource( selectedDataFile ) );
			m_dataFile = selectedDataFile;
			LogManager.getInstance().log( "info", "Data file '" + m_dataFile.getAbsolutePath() + "' validated.", true );
			
			setChanged();
			notifyObservers();
		}
		catch( SAXException e )
		{
			LogManager.getInstance().log( "excp", e, true );
			LogManager.getInstance().log( "err", "Invalid content in the data file '" + selectedDataFile.getAbsolutePath() + "'.", true );
		}
		catch( IOException e )
		{
			LogManager.getInstance().log( "excp", e, true );
			LogManager.getInstance().log( "err", "Error opening the data file '" + selectedDataFile.getAbsolutePath() + "'.", true );
		}
	}
	
	public void loadCardFile( File selectedCardFile )
	{
		try
		{
			m_cardFile = null;
			m_schemaFactory.newSchema( new File( "data/card.xsd" ) ).newValidator().validate( new StreamSource( selectedCardFile ) );
			m_cardFile = selectedCardFile;
			LogManager.getInstance().log( "info", "Card file '" + m_cardFile.getAbsolutePath() + "' validated.", true );
			
			setChanged();
			notifyObservers();
		}
		catch( SAXException e )
		{
			LogManager.getInstance().log( "excp", e, true );
			LogManager.getInstance().log( "err", "Invalid content in the card file '" + selectedCardFile.getAbsolutePath() + "'.", true );
		}
		catch( IOException e )
		{
			LogManager.getInstance().log( "excp", e, true );
			LogManager.getInstance().log( "err", "Error opening the card file '" + selectedCardFile.getAbsolutePath() + "'.", true );
		}
	}
	
	public void populate()
	{
		if( isReady() )
		{
			m_fillingThread = new FillingThread( m_cardFile, m_dataFile );
			m_fillingThread.start();
			
			setChanged();
			notifyObservers();
		}
	}
	
	public boolean isReady()
	{
		return m_dataFile != null && m_cardFile != null && !isPopulating() ;
	}
	
	public boolean isPopulating()
	{
		return m_fillingThread != null && m_fillingThread.getState() != Thread.State.TERMINATED;
	}

	// Thread used to populate the smart card
	private FillingThread m_fillingThread;

	// Data file
	private File m_dataFile;
	
	// Card config file
	private File m_cardFile;
	
	// XML schema factory
	private SchemaFactory m_schemaFactory;
}
